import * as i0 from '@angular/core';
import { InjectionToken, makeEnvironmentProviders, input, model, inject, ElementRef, NgZone, Directive, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';
import { NgModel, FormsModule } from '@angular/forms';

const HIGHLIGHTJS_CONFIG = new InjectionToken('HighlightJs-Config');
function provideSFConfig(options) {
    const provides = [
        {
            provide: HIGHLIGHTJS_CONFIG,
            useValue: {
                lang: 'html',
                ...options,
            },
        },
    ];
    return makeEnvironmentProviders(provides);
}

class HighlightJsDirective {
    constructor() {
        this.options = input();
        this.l = input('html', { alias: 'lang' });
        this.code = model();
        this.mode = input('simple');
        this.el = inject(ElementRef);
        this.ngModel = inject(NgModel, { optional: true });
        this.doc = inject(DOCUMENT);
        this.cog = inject(HIGHLIGHTJS_CONFIG, { optional: true });
        this.ngZone = inject(NgZone);
        Object.assign(this, this.cog);
    }
    escapeHTML(str) {
        return (str || '').replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;').replace(/"/g, '&quot;').replace(/'/g, '&apos;');
    }
    init() {
        this.ngZone.runOutsideAngular(() => {
            this.destroy();
            const el = this.el.nativeElement;
            const code = this.code() ?? '' + el.innerHTML.trim();
            const doc = this.doc;
            this.codeEl = doc.createElement(this.mode() === 'default' ? 'div' : 'pre');
            if (this.codeEl == null)
                return;
            const isSimple = this.mode() === 'simple';
            if (isSimple) {
                const lang = this.l();
                if (lang) {
                    this.codeEl.className = lang;
                }
                this.parentEl = el.parentNode;
                this.parentEl.insertBefore(this.codeEl, el.nextSibling);
            }
            else {
                this.parentEl = el;
                this.parentEl.innerHTML = ``;
                this.parentEl.appendChild(this.codeEl);
            }
            this.codeEl.innerHTML = code;
            const hljs = doc.defaultView.hljs;
            if (hljs == null) {
                if (typeof ngDevMode === 'undefined' || ngDevMode) {
                    console.warn(`Can't find hljs under window`);
                }
                return;
            }
            hljs.configure({ ...this.options() });
            if (isSimple) {
                hljs.highlightElement(this.codeEl);
            }
            else {
                this.codeEl.querySelectorAll('pre code').forEach((block) => {
                    hljs.highlightElement(block);
                });
            }
        });
    }
    destroy() {
        if (this.codeEl && this.parentEl) {
            this.parentEl.removeChild(this.codeEl);
            this.codeEl = undefined;
        }
    }
    ngAfterViewInit() {
        this.init();
        if (this.ngModel) {
            this.modelValue$ = this.ngModel.valueChanges?.subscribe((res) => {
                this.code.set(this.escapeHTML(res));
                this.init();
            });
        }
        else {
            this.initMutation();
        }
    }
    ngOnDestroy() {
        this.destroy();
        this.observer?.disconnect();
        this.modelValue$?.unsubscribe();
    }
    initMutation() {
        if (typeof MutationObserver === 'undefined') {
            return;
        }
        this.ngZone.runOutsideAngular(() => {
            this.observer = new MutationObserver(this.init.bind(this));
            this.observer.observe(this.el.nativeElement, {
                characterData: true,
                childList: true,
                subtree: true,
            });
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: HighlightJsDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "19.0.0", type: HighlightJsDirective, isStandalone: true, selector: "[highlight-js]", inputs: { options: { classPropertyName: "options", publicName: "options", isSignal: true, isRequired: false, transformFunction: null }, l: { classPropertyName: "l", publicName: "lang", isSignal: true, isRequired: false, transformFunction: null }, code: { classPropertyName: "code", publicName: "code", isSignal: true, isRequired: false, transformFunction: null }, mode: { classPropertyName: "mode", publicName: "mode", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { code: "codeChange" }, host: { properties: { "style.display": "mode() === 'simple' ? 'none' : null" } }, exportAs: ["highlightJs"], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: HighlightJsDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[highlight-js]',
                    host: {
                        '[style.display]': `mode() === 'simple' ? 'none' : null`,
                    },
                    exportAs: 'highlightJs',
                }]
        }], ctorParameters: () => [] });

const DIRECTIVES = [HighlightJsDirective];
class HighlightJsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: HighlightJsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.0", ngImport: i0, type: HighlightJsModule, imports: [FormsModule, HighlightJsDirective], exports: [HighlightJsDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: HighlightJsModule, imports: [FormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.0", ngImport: i0, type: HighlightJsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [FormsModule, ...DIRECTIVES],
                    exports: DIRECTIVES,
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { HIGHLIGHTJS_CONFIG, HighlightJsDirective, HighlightJsModule, provideSFConfig };
//# sourceMappingURL=ngx-highlight-js.mjs.map
